\name{GetFitARLS}
\alias{GetFitARLS}
\title{Fit AR Using Least-Squares}
\description{
For ARp subset models, the least squares estimates are
computed. The exact loglikelihood is then determined.
The estimated parameters are checked to see if they are in
the AR admissible region. 
}
\usage{
GetFitARLS(z, pvec)
}
\arguments{
  \item{z}{ vector or ts object, the time series }
  \item{pvec}{ lags included in subset AR. If pvec=0, white noise assumed. }
}
\details{
The R function \code{\link{lsfit}} is used.
}
\value{
a list with components:
  \item{loglikeliihood }{the exact loglikelihood} 
  \item{phiHat }{estimated AR parameters}
  \item{constantTerm }{constant term in the linear regression}
  \item{lags }{estimated AR parameters}
  \item{res }{the least squares regression residuals}
  \item{yX}{the dependent variable column prepended to the columns of independent variables}
  \item{InvertibleQ}{True, if the estimated parameters are in the
     AR admissible region.}
}
\references{ 
McLeod, A.I. and Zhang, Y. (2006).  
Partial autocorrelation parameterization for subset autoregression.  
Journal of Time Series Analysis, 27, 599-612.
}
\author{ A.I. McLeod }
\note{ 
This is a helper function for \code{\link{FitARLS}}. 
Normally the user would \code{\link{FitARLS}} since this
function provides generic print, summary, resid and plot methods but
GetFitARLS is sometimes useful in iterative computations like
bootstrapping since it is faster.
 }
\seealso{ 
\code{\link{FitARLS}}, 
\code{\link{FitAR}}, 
\code{\link{GetFitAR}}, 
\code{\link{LoglikelihoodAR}}
\code{\link{SelectModel}}
}
\examples{
#Fit subset AR using GetFitARLS and FitARLS
data(SeriesA)
ansLS<-GetFitARLS(SeriesA, c(1,2,7))
ans<-FitARLS(SeriesA, c(1,2,7))
ansLS
ans
summary(ans)
summary(resid(ans))
plot(ans)
}
\keyword{ ts }
