"SelectModel" <-
function(z, lag.max=15, SubsetModel=c("n","p","z"), method="AIC", Best=3, Candidates=5){
stopifnot(length(z)>0, length(z)>lag.max, lag.max>1, Best>0, Candidates>0)
BestCandidates<-Candidates
if (Best > BestCandidates)
    BestCandidates<-Best
sset<-substr(SubsetModel[1],1,1)
if (sset=="p")
    return(GetLeapsAR(z, lag.max=lag.max, method=method, Best=Best, BestCandidates))
SubsetQ <- sset!="n"
zta<-ARToPacf(ar.burg(z,aic=FALSE,order.max=lag.max)$ar)
n<-length(z)
LagRange<-1:lag.max
if (method=="AIC")
    penalty<-2*(1+LagRange)
else
    penalty<-log(n)*(1+LagRange)
if (SubsetQ)
    LagsEntering<-order(abs(zta),decreasing=TRUE)
else  
    LagsEntering<-1:lag.max
LLapprox <- n*log(cumprod(1-zta[LagsEntering]^2))
ABIC <- LLapprox + penalty
IndCandidates<-order(ABIC)[1:BestCandidates]
ABICexact<-numeric(BestCandidates+1)
if (SubsetQ){
    m<-as.list(numeric(BestCandidates+1))
    for (isub in 1:BestCandidates){
        ModelLags<-sort(LagsEntering[1:IndCandidates[isub]])
        LL<-GetFitAR(z-mean(z), ModelLags)$loglikelihood
        k<-length(ModelLags)+1 #mean is included and k>=2 here
        if (method=="AIC"){
            AIC <- -2*LL+2*k
            ABICexact[isub]<-AIC
            m[[isub]] <- list(p=ModelLags, AIC=AIC)
            }
        else {
            BIC <- -2*LL+log(n)*k
            ABICexact[isub]<-BIC
            m[[isub]] <- list(p=ModelLags, BIC=BIC)
            }
        }
        #null model
        LL<-GetFitAR(z-mean(z), 0)$loglikelihood
        if (method=="AIC"){
            AIC <- -2*LL+2
            ABICexact[BestCandidates+1] <- AIC
            m[[BestCandidates+1]]<-list(p=0,AIC=AIC)
            }
        else {
            BIC <- -2*LL+log(n)
            ABICexact[BestCandidates+1] <- BIC
            m[[BestCandidates+1]]<-list(p=0,BIC=BIC)
            }
        #final model select based on exact likelihood
        i<-order(ABICexact)
        m<-m[i]
        m<-m[1:Best]               
        if (sset=="p")
            attr(m, "model")<-"ARp"
        else
            attr(m, "model")<-"ARz"
}
else  {
    ABICexact<-numeric(BestCandidates)
    for (i in 1:BestCandidates){
        p<-LagsEntering[IndCandidates[i]]-1
        ans<-GetFitAR(z-mean(z), 0:p)
        LL<-ans$loglikelihood
#mean included in all models
        if (method=="AIC")
                penalty<-2*(p+1)
        else
                penalty<-log(n)*(p+1)
        ABICexact[i]<- -2*LL+penalty
    }
    m<-c(LagsEntering[IndCandidates]-1,ABICexact)
    m<-matrix(m,ncol=2)
    m<-m[order(ABICexact),]
    m<-m[1:Best,]
    if (Best > 1)
        if (method=="AIC")
            dimnames(m)<-c(list(1:Best),list(c("p", "AIC")))
        else
            dimnames(m)<-c(list(1:Best),list(c("p", "BIC")))
    }
class(m)<-"Selectmodel"
if (Best > 1)
    m
else 
    if (is.list(m))
        m[[1]]$p
    else
        as.vector(m[1])
}

