\name{FitARLS}
\alias{FitARLS}
\title{ Fit subset AR using OLS }
\description{
The usual subset AR model is defined by selecting a subset of the AR coefficients
and setting all other coefficients to zero.  Usually this subset model is fit using
least squares.
}

\usage{
FitARLS(z, p, SubsetQ = FALSE, lag.max = "default")
}

\arguments{
  \item{z}{ time series }
  \item{p}{ Vector specifying which lags to use in the AR. If SubsetQ=FALSE,
  p should be a scalar and a regular AR(p) will be fit.  For p=0, white noise.}
  \item{SubsetQ}{ default FALSE. Ignored if p has length > 1. Need set to TRUE for ambiguous cases -- see Note.}
  \item{lag.max}{ The maximum lag to be used in the Portmanteau Test }
}

\details{
The design matrix, X, is formed by concatenating together the needed columns and
then the R function lsfit is used.
An intercept term is used with lsfit.
The residuals are computed using BackcastResidualsAR.
The exact loglikelihood is computed using LoglikelihoodAR.  
}

\value{
  A list with class name "FitAR" and components: 
  \item{loglikelihood }{value of the loglikelihood using LoglikelihoodAR}
  \item{phiHat }{coefficients in AR(p) -- including 0's}
  \item{sigsqHat }{innovation variance estimate}
  \item{muHat }{estimate of the mean}
  \item{covHat }{covariance matrix of the coefficient estimates}
  \item{zetaHat }{transformed parameters, length(zetaHat)=\# coefficients estimated}
  \item{RacfMatrix }{residual autocorrelations and sd for lags 1...lag.max}
  \item{LjungBox}{table of Ljung-Box portmanteau test statistics}
  \item{SubsetQ }{parameters in AR(p) -- including 0's}
  \item{res}{innovation residuals, same length as z}
  \item{fits}{fitted values, same length as z}
  \item{SubsetQ }{parameters in AR(p) -- including 0's}
  \item{lags }{lags used in AR model}
  \item{demean }{TRUE if mean estimated otherwise assumed zero}
  \item{FitMethod }{"LS" for this function}
  \item{tsp}{tsp(z)}
  \item{call}{result from match.call() showing how the function was called}
  \item{yX}{the dependent variable column prepended to the columns of independent variables}
  \item{ModelTitle}{description of model}
  \item{DataTitle}{returns attr(z,"title") }
}

\note{
If SubsetQ=FALSE, this is equivalent to the built-in function ar( ..., method="OLS").
Note that least-squares residuals are not used.
The residuals are calculated using BackcastResidualsAR and the
loglikelihood is calculated using LoglikelihoodAR.
}

\references{ 
Tong, H. (1977).
Some comments on the Canadian lynx data.
Journal of the Royal Statistical Society A 140, 432-436.
} 

\author{ A.I. McLeod }

\seealso{ 
 \code{\link{FitAR}}, 
 \code{\link{LoglikelihoodAR}}, 
 \code{\link{BackcastResidualsAR}}, 
 \code{\link{ar}} 
 }

\examples{
#Compare the fit achieved by the two types of subset models
z<-log(lynx)
pvec<-SelectModel(z, SubsetModel="z", method="BIC", lag.max=12, Best=1)
pvec
FitARLS(z, pvec)
FitAR(z, pvec)
}
\keyword{ ts }
