\name{GetFitAR}
\alias{GetFitAR}
\title{ Fit AR(p) }
\description{
Obtains the exact MLE for AR(p) or subset AR model.
This function is used by FitAR.
One might prefer to use GetFitAR for applications such
as bootstrapping since it is faster than FitAR.
}
\usage{
GetFitAR(z, pvec, MeanValue=0, ...)
}
\arguments{
  \item{z}{ time series }
  \item{pvec}{lags included in AR model. If pvec=0, white noise model assumed. }
  \item{MeanValue}{by default it is assumed the mean of z is 0 }
  \item{\dots}{ optional arguments passed through to optim }
}
\details{
The built-in function optim is used to obtain the MLE estimates for
an AR or subset AR.
}
\value{
  \item{loglikelihood}{value of maximized loglikelihood}
  \item{zetaHat}{estimated zeta parameters}
  \item{phiHat}{estimated phi parameters}
  \item{convergence}{result from optim}
}
\references{ 
McLeod, A.I. and Zhang, Y. (2006).  
Partial autocorrelation parameterization for subset autoregression.  
Journal of Time Series Analysis, 27, 599-612.
}
\author{ A.I. McLeod }

\seealso{ \code{\link{FitAR}} }
\examples{
#compare results from GetFitAR and FitAR
z<-log(lynx)
z<-z - mean(z)
GetFitAR(z, c(1,2,8))
out<-FitAR(log(lynx), c(1,2,8))
out
coef(out)
}
\keyword{ ts }
