\name{GetLeapsAR}
\alias{GetLeapsAR}
\title{ Select lags for best subset AR-phi model }

\description{
The subset AR-phi model is the usual subset model, for example see Tong (1977).
This function is used by SelectModel for model identification for
AR-phi models.
}

\usage{
GetLeapsAR(z, lag.max = 15, method = "AIC", Best = 3, Candidates=5)
}

\arguments{
  \item{z}{ ts object or vector containing time series }
  \item{lag.max}{ maximum order of the AR }
  \item{method}{ choices are "AIC" or "BIC" }
  \item{Best}{ the number of based selected based on highest AIC/BIC }
  \item{Candidates}{ number of models initially selected using the approximate criterion }
}

\details{
The R function leaps in the R package leaps is used to compute the subset
regression model with the smallest residual sum of squares containing
1,...,lag.max parameters.  The mean is always included, so the only
parameters considered are the phi coefficients. After the best models
containing 1,..,lag.max parameters are selected the models are individually
refit using GetFitARLS to determine the exact likelihood function
for each selected model. Based on this likelihood the AIC or BIC criterion is
computed and then the best models are selected.
}

\value{
a list with components
  \item{NumParameters} {Number of parameters in model}
  \item{AIC} {approximate AIC (McLeod and Zhang, 2006a, eqn. 15), if method=="AIC"}
  \item{BIC} {approximate BIC (McLeod and Zhang, 2006a, eqn. 15), if method=="BIC"}
  \item{p} {lags present}
}

\references{ 
Tong, H. (1977)
Some comments on the Canadian lynx data.
Journal of the Royal Statistical Society A 140, 432-436. 
}

\author{ A.I. McLeod }

\note{Requires leaps package}

\section{Warning }{
AIC and BIC values produced are not comparable to AIC and BIC produced
by SelectModel for AR-zeta models. 
However comparable AIC/BIC values are produced when the selected models
are fit by FitARLS or FitAR respectively.
}

\seealso{
 \code{\link{SelectModel}}, 
 \code{\link{GetFitARLS}},
 \code{\link{leaps}} 
}

\examples{
#for the log(lynx) Tong (1977) selected an AR-phi(1,2,4,10,11)
#using the AIC and a subset selection algorithm. Our more exact
#approach shows that the AR-phi(1,2,3,4,10,11) has slightly lower
#AIC (using exact likelihood evaluation).  
z<-log(lynx)
GetLeapsAR(z, lag.max=11)
GetLeapsAR(z, lag.max=11, method="BIC")
}

\keyword{ ts }
