\name{TimeSeriesPlot}
\alias{TimeSeriesPlot}
\title{ Multipanel trellis style time series plot }
\description{
Cleveland pointed out that the aspect-ratio is important in graphically
showing the rate-of-change or shape information. For many time series,
it is preferably to set this ratio to 0.25 than the default.  In general,
Cleveland shows that the best choice of aspect-ratio is often obtained
by if the average apparent absolute slope in the graph is about 45 deg.
But for many stationary time series, this would result in an aspect-ratio
which would be too small. 
As a comprise we have chosen a default of 0.25 but the user can select 
other choices.
}
\usage{
TimeSeriesPlot(z, SubLength = 200, aspect = 0.25, type="l", ylab=NULL, main=NULL, ...)
}
\arguments{
  \item{z}{ ts object or vector, time series data }
  \item{SubLength}{ maximum number of data points per panel }
  \item{aspect}{ optional setting for the aspect-ratio }
  \item{type}{ plot type, default type="l" join points with lines}
  \item{ylab}{optional label for vertical axis }
  \item{main}{ optional title}
  \item{...}{ optional arguments passed to \code{xyplot} }
}
\details{
If z has attribute "title" containing a character string, this is used
on the plot.  
Time series input using the function \code{\link{Readts}} always
have this attribute set.
}

\value{
graphic object of class trellis is produced
}

\references{ W.S. Cleveland (1993), Visualizing Data. }
\author{ A.I. McLeod }

\note{ requires lattice library }


\seealso{ 
\code{\link{TracePlot}},
\code{\link{Readts}}
 }

\examples{
data(Ninemile)
TimeSeriesPlot(Ninemile)
}

\keyword{ ts }
