\name{TracePlot}
\alias{TracePlot}
\title{plot time series controlling the aspect-ratio }
\description{
Cleveland (1993) pointed out that the aspect-ratio is important in graphically
showing the rate-of-change or shape information. For many time series,
it is preferably to set this ratio to 0.25 than the default.  In general,
Cleveland shows that the best choice of aspect-ratio is often obtained
by if the average apparent absolute slope in the graph is about 45 deg.
But for many stationary time series, this would result in an aspect-ratio
which would be too small. 
As a comprise we have chosen a default of 0.25 but the user can select 
other choices.
}
\usage{
TracePlot(z, aspect = 0.25, type = "l", ylab=NULL, main=NULL, ...)
}
\arguments{
  \item{z}{ a ts-object or vector containing the time series }
  \item{aspect}{ desired aspect-ratio for plot }
  \item{type}{ plot type, default type="l" join points with lines}
  \item{ylab}{ vertical axis title}
  \item{main}{ optional title}
  \item{...}{optional arguments passed to plot}
}
\details{
If z has attribute "title" containing a character string, this is used
on the plot.  
Time series input using the function \code{\link{readts}} always
have this attribute set.

}
\value{no return value}
\references{ W.S. Cleveland (1993), Visualizing Data. }
\author{ A.I. McLeod }
\note{  
The aspect-ratio may also be controlled in the lattice function xyplot
that is used in the function TimeSeriesPlot.
}
\seealso{\code{\link{ts}}, 
\code{\link{plot.ts}},
\code{\link{ts.plot}},
\code{\link{Readts}},
\code{\link{TimeSeriesPlot}}
 }
\examples{
#from built-in datasets
 TracePlot(AirPassengers)
 title(main="Monthly number of trans-Atlantic airline passengers")
#
#compare plots for lynx series
plot(lynx)
win.graph()
TracePlot(lynx, type="o", pch=16, ylab="# pelts", main="Lynx Trappings")
}
\keyword{ ts }
